Training functionality for custom morphological models.
This module provides functions for training custom morphological analysis models from annotated corpora.
Functions
- define
- Defines train and export module functions in the given Ruby module.