Error types for Lindera operations.
This module provides error types used throughout the Lindera Ruby bindings.
Functions
- to_
magnus_ error - Converts a Lindera error message into a Magnus Ruby error.
Error types for Lindera operations.
This module provides error types used throughout the Lindera Ruby bindings.