Token representation for morphological analysis results.
This module wraps Lindera tokens for use in Ruby.
Structs
- RbToken
- Token object wrapping the Rust Token data.
Functions
- define
- Defines the Token class in the given Ruby module.